==> gromacs_2016.1.orig.tar.gz: gromacs-2016.1/src/gromacs/listed-forces/orires.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2010,2014,2015, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares functions for handling orientation restraints.
 *
 * \inlibraryapi
 * \ingroup module_listed-forces
 */
#ifndef GMX_LISTED_FORCES_ORIRES_H
#define GMX_LISTED_FORCES_ORIRES_H

#include <cstdio>

#include "gromacs/topology/ifunc.h"

struct gmx_mtop_t;
struct gmx_multisim_t;
struct history_t;
struct t_inputrec;
struct t_pbc;
struct t_commrec;
struct t_fcdata;
struct t_oriresdata;
struct t_state;

/*! \brief
 * Decides whether orientation restraints can work, and initializes
 * all the orientation restraint stuff in *od (and assumes *od is
 * already allocated.
 */
void init_orires(FILE *fplog, const gmx_mtop_t *mtop,
                 rvec x[],
                 const t_inputrec *ir,
                 const t_commrec *cr, t_oriresdata *od,
                 t_state *state);

/*! \brief
 * Calculates the time averaged D matrices, the S matrix for each experiment.
 *
 * Returns the weighted RMS deviation of the orientation restraints.
 */
real calc_orires_dev(const gmx_multisim_t *ms,
                     int nfa, const t_iatom fa[], const t_iparams ip[],
                     const t_mdatoms *md, const rvec x[],
                     const t_pbc *pbc, t_fcdata *fcd, history_t *hist);

/*! \brief
 * Diagonalizes the order tensor(s) of the orienation restraints.
 *
 * For each experiment eig containts first 3 eigenvalues and then
 * the 3 eigenvectors. The eigenvalues are ordered on magnitude.
 */
void diagonalize_orires_tensors(t_oriresdata *od);

//! Prints order parameter, eigenvalues and eigenvectors to the log file.
void print_orires_log(FILE *log, t_oriresdata *od);

//! Calculates the orientation restraint forces.
t_ifunc orires;

//! Copies the new time averages that have been calculated in calc_orires_dev.
void update_orires_history(t_fcdata *fcd, history_t *hist);

#endif

==> gromacs_2018.1.orig.tar.gz: gromacs-2018.1/src/gromacs/listed-forces/orires.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2010,2014,2015,2017, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares functions for handling orientation restraints.
 *
 * \inlibraryapi
 * \ingroup module_listed-forces
 */
#ifndef GMX_LISTED_FORCES_ORIRES_H
#define GMX_LISTED_FORCES_ORIRES_H

#include <cstdio>

#include "gromacs/topology/ifunc.h"

struct gmx_mtop_t;
struct gmx_multisim_t;
class history_t;
struct t_inputrec;
struct t_pbc;
struct t_commrec;
struct t_fcdata;
struct t_oriresdata;
class t_state;

/*! \brief
 * Decides whether orientation restraints can work, and initializes
 * all the orientation restraint stuff in *od (and assumes *od is
 * already allocated.
 * If orientation restraint are used, globalState is read and modified
 * on the master rank (which is the only rank, since orientation
 * restraints can not run in parallel).
 */
void init_orires(FILE             *fplog,
                 const gmx_mtop_t *mtop,
                 const t_inputrec *ir,
                 const t_commrec  *cr,
                 t_state          *globalState,
                 t_oriresdata     *od);

/*! \brief
 * Calculates the time averaged D matrices, the S matrix for each experiment.
 *
 * Returns the weighted RMS deviation of the orientation restraints.
 */
real calc_orires_dev(const gmx_multisim_t *ms,
                     int nfa, const t_iatom fa[], const t_iparams ip[],
                     const t_mdatoms *md, const rvec x[],
                     const t_pbc *pbc, t_fcdata *fcd, history_t *hist);

/*! \brief
 * Diagonalizes the order tensor(s) of the orienation restraints.
 *
 * For each experiment eig containts first 3 eigenvalues and then
 * the 3 eigenvectors. The eigenvalues are ordered on magnitude.
 */
void diagonalize_orires_tensors(t_oriresdata *od);

//! Prints order parameter, eigenvalues and eigenvectors to the log file.
void print_orires_log(FILE *log, t_oriresdata *od);

//! Calculates the orientation restraint forces.
t_ifunc orires;

//! Copies the new time averages that have been calculated in calc_orires_dev.
void update_orires_history(t_fcdata *fcd, history_t *hist);

#endif
